@@ -1,8 +1,10 @@
-Index: ruby-gsl/ext/extconf.rb
-===================================================================
---- ruby-gsl.orig/ext/extconf.rb	2011-06-05 20:57:36.000000000 +0900
-+++ ruby-gsl/ext/extconf.rb	2011-06-05 20:58:59.000000000 +0900
-@@ -234,7 +234,7 @@
+Description: install in $vendorarchdir according to Debian Ruby Policy
+Origin: vendor
+Last-Update: 2013-10-16
+
+--- a/ext/extconf.rb
++++ b/ext/extconf.rb
+@@ -243,7 +243,7 @@
  end
  
  #narray_config = dir_config("narray")
@@ -11,7 +13,7 @@ Index: ruby-gsl/ext/extconf.rb
  # Try to find narray with RubyGems
  begin
    require 'rubygems'
-@@ -253,7 +253,7 @@
+@@ -262,7 +262,7 @@
    end
  end
  
